INSTALLATION NOTES
==================

1 - Prerequisites
-----------------

Source code from versioning system
'''''''''''''''''''''''''''''''''''

Prior to any extensive usage of "python setup.py" commands, you should run::

    $ ./autogen.sh

To prepare the source code for build system.

Source code from tarball
''''''''''''''''''''''''

You can directly skip to Part 2.

2 - Install
-----------

To install this code in your system, you can simply run::

   $ python setup.py install

